**Example 1: 强制释放 Prometheus 实例**



Input: 

```
tccli monitor DestroyPrometheusInstance --cli-unfold-argument  \
    --InstanceId prom-w3rkj7835b
```

Output: 
```
{
    "Response": {
        "RequestId": "3e0dff9d-9ed5-47c3-beb2-a42c1d69e1cc"
    }
}
```

